pub enum BackgroundLayer {
Color {
color: Color,
},
LinearGradient {
angle: Option<f32>,
stops: Vec<GradientStop>,
},
RadialGradient {
shape: Option<RadialShape>,
position: Option<TransformOrigin>,
stops: Vec<GradientStop>,
},
ConicGradient {
from: Option<f32>,
position: Option<TransformOrigin>,
stops: Vec<GradientStop>,
},
Image {
url: String,
size: Option<BackgroundSize>,
position: Option<TransformOrigin>,
repeat: Option<BackgroundRepeat>,
},
}Variants
Color
LinearGradient
RadialGradient
ConicGradient
Image
Fields

size: Option<BackgroundSize>
position: Option<TransformOrigin>
repeat: Option<BackgroundRepeat>Trait Implementations
Sourceimpl Clone for BackgroundLayer
impl Clone for BackgroundLayer
Sourcefn clone(&self) -> BackgroundLayer
fn clone(&self) -> BackgroundLayer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BackgroundLayer
impl Debug for BackgroundLayer
Sourceimpl<'de> Deserialize<'de> for BackgroundLayer
impl<'de> Deserialize<'de> for BackgroundLayer
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BackgroundLayer
impl JsonSchema for BackgroundLayer
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BackgroundLayer
impl PartialEq for BackgroundLayer
Sourceimpl Serialize for BackgroundLayer
impl Serialize for BackgroundLayer
impl StructuralPartialEq for BackgroundLayer