pub struct BorderSide {
pub width: Option<Length>,
pub style: Option<BorderStyle>,
pub color: Option<Color>,
}Fields
width: Option<Length>style: Option<BorderStyle>color: Option<Color>Trait Implementations
Sourceimpl Clone for BorderSide
impl Clone for BorderSide
Sourcefn clone(&self) -> BorderSide
fn clone(&self) -> BorderSide
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BorderSide
impl Debug for BorderSide
Sourceimpl Default for BorderSide
impl Default for BorderSide
Sourcefn default() -> BorderSide
fn default() -> BorderSide
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for BorderSidewhere
BorderSide: Default,
impl<'de> Deserialize<'de> for BorderSidewhere
BorderSide: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BorderSide
impl JsonSchema for BorderSide
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BorderSide
impl PartialEq for BorderSide
Sourceimpl Serialize for BorderSide
impl Serialize for BorderSide
impl StructuralPartialEq for BorderSide