pub struct GradientStop {
pub color: Color,
pub offset: Option<f32>,
}Fields
color: Coloroffset: Option<f32>Trait Implementations
Sourceimpl Clone for GradientStop
impl Clone for GradientStop
Sourcefn clone(&self) -> GradientStop
fn clone(&self) -> GradientStop
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GradientStop
impl Debug for GradientStop
Sourceimpl Default for GradientStop
impl Default for GradientStop
Sourceimpl<'de> Deserialize<'de> for GradientStopwhere
GradientStop: Default,
impl<'de> Deserialize<'de> for GradientStopwhere
GradientStop: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GradientStop
impl JsonSchema for GradientStop
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GradientStop
impl PartialEq for GradientStop
Sourceimpl Serialize for GradientStop
impl Serialize for GradientStop
impl StructuralPartialEq for GradientStop