pub struct TextDecoration {
pub line: Option<TextDecorationLine>,
pub style: Option<TextDecorationStyle>,
pub color: Option<Color>,
pub thickness: Option<Length>,
}Fields
line: Option<TextDecorationLine>style: Option<TextDecorationStyle>color: Option<Color>thickness: Option<Length>Trait Implementations
Sourceimpl Clone for TextDecoration
impl Clone for TextDecoration
Sourcefn clone(&self) -> TextDecoration
fn clone(&self) -> TextDecoration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextDecoration
impl Debug for TextDecoration
Sourceimpl Default for TextDecoration
impl Default for TextDecoration
Sourcefn default() -> TextDecoration
fn default() -> TextDecoration
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TextDecorationwhere
TextDecoration: Default,
impl<'de> Deserialize<'de> for TextDecorationwhere
TextDecoration: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextDecoration
impl JsonSchema for TextDecoration
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TextDecoration
impl PartialEq for TextDecoration
Sourceimpl Serialize for TextDecoration
impl Serialize for TextDecoration
impl StructuralPartialEq for TextDecoration