pub struct TransformOrigin {
pub x: Option<LengthPercentage>,
pub y: Option<LengthPercentage>,
pub z: Option<Length>,
}Fields
x: Option<LengthPercentage>y: Option<LengthPercentage>z: Option<Length>Trait Implementations
Sourceimpl Clone for TransformOrigin
impl Clone for TransformOrigin
Sourcefn clone(&self) -> TransformOrigin
fn clone(&self) -> TransformOrigin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransformOrigin
impl Debug for TransformOrigin
Sourceimpl Default for TransformOrigin
impl Default for TransformOrigin
Sourcefn default() -> TransformOrigin
fn default() -> TransformOrigin
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TransformOriginwhere
TransformOrigin: Default,
impl<'de> Deserialize<'de> for TransformOriginwhere
TransformOrigin: Default,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TransformOrigin
impl JsonSchema for TransformOrigin
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TransformOrigin
impl PartialEq for TransformOrigin
Sourceimpl Serialize for TransformOrigin
impl Serialize for TransformOrigin
impl StructuralPartialEq for TransformOrigin