pub struct BackgroundTransition {
pub duration: f64,
pub easing: EasingType,
}Expand description
Transition configuration for background interpolation between scenes.
Fields
duration: f64easing: EasingTypeTrait Implementations
Sourceimpl Clone for BackgroundTransition
impl Clone for BackgroundTransition
Sourcefn clone(&self) -> BackgroundTransition
fn clone(&self) -> BackgroundTransition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BackgroundTransition
impl Debug for BackgroundTransition
Sourceimpl<'de> Deserialize<'de> for BackgroundTransition
impl<'de> Deserialize<'de> for BackgroundTransition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BackgroundTransition
impl JsonSchema for BackgroundTransition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for BackgroundTransition
impl RefUnwindSafe for BackgroundTransition
impl Send for BackgroundTransition
impl Sync for BackgroundTransition
impl Unpin for BackgroundTransition
impl UnsafeUnpin for BackgroundTransition
impl UnwindSafe for BackgroundTransition