pub struct GradientShiftConfig {
pub colors: Vec<String>,
pub gradient_type: GradientType,
}Expand description
Config for the gradient_shift preset.
Fields
colors: Vec<String>gradient_type: GradientTypeTrait Implementations
Sourceimpl Clone for GradientShiftConfig
impl Clone for GradientShiftConfig
Sourcefn clone(&self) -> GradientShiftConfig
fn clone(&self) -> GradientShiftConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GradientShiftConfig
impl Debug for GradientShiftConfig
Sourceimpl<'de> Deserialize<'de> for GradientShiftConfig
impl<'de> Deserialize<'de> for GradientShiftConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GradientShiftConfig
impl JsonSchema for GradientShiftConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GradientShiftConfig
impl RefUnwindSafe for GradientShiftConfig
impl Send for GradientShiftConfig
impl Sync for GradientShiftConfig
impl Unpin for GradientShiftConfig
impl UnsafeUnpin for GradientShiftConfig
impl UnwindSafe for GradientShiftConfig