pub struct GridDotsConfig {
pub color: String,
pub element_size: f32,
pub spacing: f32,
}Expand description
Config for the grid_dots preset.
Fields
color: Stringelement_size: f32spacing: f32Trait Implementations
Sourceimpl Clone for GridDotsConfig
impl Clone for GridDotsConfig
Sourcefn clone(&self) -> GridDotsConfig
fn clone(&self) -> GridDotsConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GridDotsConfig
impl Debug for GridDotsConfig
Sourceimpl<'de> Deserialize<'de> for GridDotsConfig
impl<'de> Deserialize<'de> for GridDotsConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GridDotsConfig
impl JsonSchema for GridDotsConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GridDotsConfig
impl RefUnwindSafe for GridDotsConfig
impl Send for GridDotsConfig
impl Sync for GridDotsConfig
impl Unpin for GridDotsConfig
impl UnsafeUnpin for GridDotsConfig
impl UnwindSafe for GridDotsConfig