pub struct HeropatternConfig {
pub pattern: String,
pub color: String,
pub opacity: f32,
pub scale: f32,
}Expand description
Config for the heropattern preset.
Fields
pattern: StringName of the heropattern (e.g. “plus”, “topography”, “jigsaw”).
color: Stringopacity: f32scale: f32Trait Implementations
Sourceimpl Clone for HeropatternConfig
impl Clone for HeropatternConfig
Sourcefn clone(&self) -> HeropatternConfig
fn clone(&self) -> HeropatternConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HeropatternConfig
impl Debug for HeropatternConfig
Sourceimpl<'de> Deserialize<'de> for HeropatternConfig
impl<'de> Deserialize<'de> for HeropatternConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HeropatternConfig
impl JsonSchema for HeropatternConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HeropatternConfig
impl RefUnwindSafe for HeropatternConfig
impl Send for HeropatternConfig
impl Sync for HeropatternConfig
impl Unpin for HeropatternConfig
impl UnsafeUnpin for HeropatternConfig
impl UnwindSafe for HeropatternConfig