pub struct AudioTrack {
pub src: String,
pub start: f64,
pub end: Option<f64>,
pub volume: f32,
pub fade_in: Option<f64>,
pub fade_out: Option<f64>,
pub volume_keyframes: Vec<VolumeKeyframe>,
}Fields
src: Stringstart: f64end: Option<f64>volume: f32fade_in: Option<f64>fade_out: Option<f64>volume_keyframes: Vec<VolumeKeyframe>Trait Implementations
Sourceimpl Clone for AudioTrack
impl Clone for AudioTrack
Sourcefn clone(&self) -> AudioTrack
fn clone(&self) -> AudioTrack
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AudioTrack
impl Debug for AudioTrack
Sourceimpl<'de> Deserialize<'de> for AudioTrack
impl<'de> Deserialize<'de> for AudioTrack
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AudioTrack
impl JsonSchema for AudioTrack
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AudioTrack
impl RefUnwindSafe for AudioTrack
impl Send for AudioTrack
impl Sync for AudioTrack
impl Unpin for AudioTrack
impl UnsafeUnpin for AudioTrack
impl UnwindSafe for AudioTrack