pub struct CameraOrigin {
pub x: f32,
pub y: f32,
}Expand description
Focal point of the camera in frame pixels.
Fields
x: f32y: f32Trait Implementations
Sourceimpl Clone for CameraOrigin
impl Clone for CameraOrigin
Sourcefn clone(&self) -> CameraOrigin
fn clone(&self) -> CameraOrigin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CameraOrigin
impl Debug for CameraOrigin
Sourceimpl Default for CameraOrigin
impl Default for CameraOrigin
Sourcefn default() -> CameraOrigin
fn default() -> CameraOrigin
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CameraOrigin
impl<'de> Deserialize<'de> for CameraOrigin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CameraOrigin
impl JsonSchema for CameraOrigin
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CameraOrigin
impl RefUnwindSafe for CameraOrigin
impl Send for CameraOrigin
impl Sync for CameraOrigin
impl Unpin for CameraOrigin
impl UnsafeUnpin for CameraOrigin
impl UnwindSafe for CameraOrigin