pub struct VideoConfig {
pub width: u32,
pub height: u32,
pub fps: u32,
pub background: String,
pub codec: Option<VideoCodec>,
pub crf: Option<u8>,
}Fields
width: u32height: u32fps: u32background: Stringcodec: Option<VideoCodec>crf: Option<u8>Trait Implementations
Sourceimpl Debug for VideoConfig
impl Debug for VideoConfig
Sourceimpl<'de> Deserialize<'de> for VideoConfig
impl<'de> Deserialize<'de> for VideoConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VideoConfig
impl JsonSchema for VideoConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VideoConfig
impl RefUnwindSafe for VideoConfig
impl Send for VideoConfig
impl Sync for VideoConfig
impl Unpin for VideoConfig
impl UnsafeUnpin for VideoConfig
impl UnwindSafe for VideoConfig