pub struct CaptionWord {
pub text: String,
pub start: f64,
pub end: f64,
}Fields
text: Stringstart: f64end: f64Trait Implementations
Sourceimpl Debug for CaptionWord
impl Debug for CaptionWord
Sourceimpl<'de> Deserialize<'de> for CaptionWord
impl<'de> Deserialize<'de> for CaptionWord
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CaptionWord
impl JsonSchema for CaptionWord
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CaptionWord
impl RefUnwindSafe for CaptionWord
impl Send for CaptionWord
impl Sync for CaptionWord
impl Unpin for CaptionWord
impl UnsafeUnpin for CaptionWord
impl UnwindSafe for CaptionWord