pub struct GradientBorder {
pub colors: Vec<String>,
pub width: f32,
pub angle: f32,
}Fields
colors: Vec<String>width: f32angle: f32Trait Implementations
Sourceimpl Clone for GradientBorder
impl Clone for GradientBorder
Sourcefn clone(&self) -> GradientBorder
fn clone(&self) -> GradientBorder
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GradientBorder
impl Debug for GradientBorder
Sourceimpl<'de> Deserialize<'de> for GradientBorder
impl<'de> Deserialize<'de> for GradientBorder
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for GradientBorder
impl JsonSchema for GradientBorder
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for GradientBorder
impl PartialEq for GradientBorder
Sourceimpl Serialize for GradientBorder
impl Serialize for GradientBorder
impl StructuralPartialEq for GradientBorder