pub struct InnerShadow {
pub color: String,
pub offset_x: f32,
pub offset_y: f32,
pub blur: f32,
}Expand description
Inner shadow configuration (inset shadow).
Fields
color: Stringoffset_x: f32offset_y: f32blur: f32Trait Implementations
Sourceimpl Clone for InnerShadow
impl Clone for InnerShadow
Sourcefn clone(&self) -> InnerShadow
fn clone(&self) -> InnerShadow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InnerShadow
impl Debug for InnerShadow
Sourceimpl<'de> Deserialize<'de> for InnerShadow
impl<'de> Deserialize<'de> for InnerShadow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for InnerShadow
impl JsonSchema for InnerShadow
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for InnerShadow
impl PartialEq for InnerShadow
Sourceimpl Serialize for InnerShadow
impl Serialize for InnerShadow
impl StructuralPartialEq for InnerShadow