pub struct KeyframesConfig {
pub keyframes: Vec<Animation>,
pub delay: f64,
pub duration: f64,
pub repeat: bool,
}Expand description
Custom keyframe animations configuration.
Fields
keyframes: Vec<Animation>delay: f64duration: f64repeat: boolTrait Implementations
Sourceimpl Clone for KeyframesConfig
impl Clone for KeyframesConfig
Sourcefn clone(&self) -> KeyframesConfig
fn clone(&self) -> KeyframesConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyframesConfig
impl Debug for KeyframesConfig
Sourceimpl<'de> Deserialize<'de> for KeyframesConfig
impl<'de> Deserialize<'de> for KeyframesConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KeyframesConfig
impl JsonSchema for KeyframesConfig
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for KeyframesConfig
impl PartialEq for KeyframesConfig
Sourceimpl Serialize for KeyframesConfig
impl Serialize for KeyframesConfig
impl StructuralPartialEq for KeyframesConfig