pub struct ShapeText {
pub content: String,
pub font_size: f32,
pub color: String,
pub font_family: String,
pub font_weight: FontWeight,
pub align: TextAlign,
pub vertical_align: VerticalAlign,
pub line_height: Option<f32>,
pub letter_spacing: Option<f32>,
pub padding: Option<f32>,
}Fields
content: Stringfont_size: f32color: Stringfont_family: Stringfont_weight: FontWeightalign: TextAlignvertical_align: VerticalAlignline_height: Option<f32>letter_spacing: Option<f32>padding: Option<f32>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ShapeText
impl<'de> Deserialize<'de> for ShapeText
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ShapeText
impl JsonSchema for ShapeText
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShapeText
impl RefUnwindSafe for ShapeText
impl Send for ShapeText
impl Sync for ShapeText
impl Unpin for ShapeText
impl UnsafeUnpin for ShapeText
impl UnwindSafe for ShapeText