pub struct TextBackground {
pub color: String,
pub padding: f32,
pub corner_radius: f32,
}Fields
color: Stringpadding: f32corner_radius: f32Trait Implementations
Sourceimpl Clone for TextBackground
impl Clone for TextBackground
Sourcefn clone(&self) -> TextBackground
fn clone(&self) -> TextBackground
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextBackground
impl Debug for TextBackground
Sourceimpl<'de> Deserialize<'de> for TextBackground
impl<'de> Deserialize<'de> for TextBackground
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextBackground
impl JsonSchema for TextBackground
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TextBackground
impl RefUnwindSafe for TextBackground
impl Send for TextBackground
impl Sync for TextBackground
impl Unpin for TextBackground
impl UnsafeUnpin for TextBackground
impl UnwindSafe for TextBackground