pub struct TextShadow {
pub color: String,
pub offset_x: f32,
pub offset_y: f32,
pub blur: f32,
}Fields
color: Stringoffset_x: f32offset_y: f32blur: f32Trait Implementations
Sourceimpl Clone for TextShadow
impl Clone for TextShadow
Sourcefn clone(&self) -> TextShadow
fn clone(&self) -> TextShadow
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextShadow
impl Debug for TextShadow
Sourceimpl<'de> Deserialize<'de> for TextShadow
impl<'de> Deserialize<'de> for TextShadow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TextShadow
impl JsonSchema for TextShadow
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TextShadow
impl RefUnwindSafe for TextShadow
impl Send for TextShadow
impl Sync for TextShadow
impl Unpin for TextShadow
impl UnsafeUnpin for TextShadow
impl UnwindSafe for TextShadow